@@ -4,15 +4,15 @@ use warnings;
 use base 'Module::Setup::Flavor';
 
 sub loader {
-    my $self = shift;
-    $self->import_template('Module::Setup::Flavor::Default');
+    my $class = shift;
+    $class->import_template('Module::Setup::Flavor::Default');
 }
 
 1;
 
 =head1
 
-Module::Setup::Flavor::CodeRepos - coderepos flavor
+Module::Setup::Flavor::Default - default flavor
 
 =head1 SYNOPSIS
 
@@ -33,6 +33,8 @@ template: |
   1;
   __END__
 
+  =encoding utf8
+
   =head1 NAME
 
   [% module %] -
