@@ -1,8 +1,7 @@
 package Module::Setup::Flavor::Default;
 use strict;
 use warnings;
-use base 'Module::Setup::Flavor::SelectVC';
-
+use base 'Module::Setup::Flavor';
 1;
 
 =head1
@@ -22,7 +21,7 @@ file: Makefile.PL
 template: |
   use inc::Module::Install;
   name '[% dist %]';
-  all_from 'lib/[% module_unix_path %].pm';
+  all_from 'lib/[% module_path %].pm';
 
   # requires '';
 
@@ -51,7 +50,6 @@ template: |
   all_pod_files_spelling_ok('lib');
   __DATA__
   [% config.author %]
-  [% config.email %]
   [% module %]
 ---
 file: xt/02_perlcritic.t
@@ -95,6 +93,8 @@ template: |
   1;
   __END__
 
+  =encoding utf8
+
   =head1 NAME
 
   [% module %] -
@@ -181,6 +181,6 @@ template: |
 config:
   plugins:
     - Config::Basic
+    - VC::SVN
     - Template
     - Test::Makefile
-    - Additional
